local_shared library

A SharedPreferences-based local storage, designed as an alternative to the localstore package

Classes

LocalShared
Parent of SharedCollection, SharedDocument and SharedManyDocument. Need to be initiated before used!
SharedCollection
Represents a collection of SharedDocument within the LocalShared storage.
SharedDocument
Represents a document within a SharedCollection in LocalShared storage.
SharedMany
Represents a response containing a list of data items.
SharedManyDocument
Representing a group of document within a SharedCollection in LocalShared storage.
SharedNone
Represents a response indicating the absence of data.
SharedOne
Represents a response containing a single data item.
SharedResponse<T extends Object>
Represents the response of an operation in LocalShared.

Extensions

FutureSharedResponseExtension on Future<SharedResponse<Object>>
Extension on Future of SharedResponse providing convenience getters for handling asynchronous responses with one or many data items.
SharedResponseExtension on SharedResponse<Object>
Extension on SharedResponse providing convenience getters for handling responses with one or many data items.

Typedefs

JSON = Map<String, dynamic>
Define Map<String, dynamic> as JSON values.
Shared = LocalShared
A shorter term for LocalShared.