SharedNone class

Represents a response indicating the absence of data.

SharedNone is used when an operation does not produce any data.

Usage example:

final response = SharedNone(success: true, message: 'Operation successful');
print(response); // SharedNone(success: true, message: 'Operation successful')
Inheritance
Available extensions

Constructors

SharedNone({bool success = false, required String message})
Creates a new instance of SharedNone.
const

Properties

data Object?
The data payload of the response.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
many List<JSON>?

Available on SharedResponse<Object>, provided by the SharedResponseExtension extension

Expect a list of JSON data if the response is SharedMany.
no setter
message String
Additional information about the operation.
finalinherited
one JSON?

Available on SharedResponse<Object>, provided by the SharedResponseExtension extension

Expect a single JSON data if the response is SharedOne.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
Indicates whether the operation was successful.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited