SharedOne class

Represents a response containing a single data item.

SharedOne is used when an operation results in a single data item. The data item is typically represented as a JSON object.

Usage example:

final response = SharedOne(success: true, message: 'Operation successful', data: {'key': 'value'});
print(response); // SharedOne(success: true, message: 'Operation successful', data: {'key': 'value'})
Inheritance

Constructors

SharedOne({bool success = false, required String message, required JSON? data})
Creates a new instance of SharedOne.
const

Properties

data JSON?
The data payload of the response.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Additional information about the operation.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
Indicates whether the operation was successful.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited