local_shared library
A SharedPreferences-based local storage, designed as an alternative to the localstore package
Classes
- Parent of SharedCollection, SharedDocument and SharedManyDocument. Need to be initiated before used!
- Represents a collection of SharedDocument within the LocalShared storage.
- Represents a document within a SharedCollection in LocalShared storage.
- Represents a response containing a list of data items.
- Representing a group of document within a SharedCollection in LocalShared storage.
- Represents a response indicating the absence of data.
- Represents a response containing a single data item.
- Represents the response of an operation in LocalShared.
Extensions
- Extension on Future of SharedResponse providing convenience getters for handling asynchronous responses with one or many data items.
- Extension on SharedResponse providing convenience getters for handling responses with one or many data items.
Typedefs
-
JSON
= Map<
String, dynamic> - Define Map<String, dynamic> as JSON values.
- A shorter term for LocalShared.