local_shared library

Lightweight local storage that uses Flutter Secure Storage and SharedPreferences.

Provides a simplified API for managing collections and documents in a key/value store. It is designed as an alternative to localstore with explicit, typed responses.

Classes

LocalShared
LocalShared is the core datastore object.
SharedCollection
A collection is a container of documents inside LocalShared.
SharedDocument
A single document stored inside a collection.
SharedMany
Represents a response containing a list of data items.
SharedManyDocument
Handles bulk operations for many documents in a collection.
SharedNone
Represents a response indicating the absence of data.
SharedOne
Represents a response containing a single data item.
SharedResponse<T extends Object>
Base class for structured results returned by LocalShared operations.

Extensions

FutureSharedResponseExtension on Future<SharedResponse<Object>>
Extension on Future of SharedResponse providing convenience getters for handling asynchronous responses with one or many data items.
JSONExtension on JSON
SharedResponseExtension on SharedResponse<Object>
Extension on SharedResponse providing convenience getters for handling responses with one or many data items.

Typedefs

JSON = Map<String, dynamic>
Define Map<String, dynamic> as JSON values.
Shared = LocalShared
A shorter term for LocalShared.