local_shared library
Lightweight local storage that uses Flutter Secure Storage and SharedPreferences.
Provides a simplified API for managing collections and documents in a key/value store.
It is designed as an alternative to localstore with explicit, typed responses.
Classes
- LocalShared is the core datastore object.
-
A collection is a container of documents inside
LocalShared. - A single document stored inside a collection.
- Represents a response containing a list of data items.
- Handles bulk operations for many documents in a collection.
- Represents a response indicating the absence of data.
- Represents a response containing a single data item.
- Base class for structured results returned by LocalShared operations.
Extensions
- Extension on Future of SharedResponse providing convenience getters for handling asynchronous responses with one or many data items.
- JSONExtension on JSON
- Extension on SharedResponse providing convenience getters for handling responses with one or many data items.
Typedefs
-
JSON
= Map<
String, dynamic> - Define Map<String, dynamic> as JSON values.
- A shorter term for LocalShared.