SharedResponse<T extends Object> class
abstract
Base class for structured results returned by LocalShared operations.
Every result communicates whether the operation succeeded and carries an informative message plus optional payload data.
- Implementers
- Available extensions
Constructors
-
Creates a new instance of SharedResponse.
const
Properties
- data → T?
-
The data payload of the response.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
many
→ List<
JSON> ? -
Available on SharedResponse<
Expect a list of JSON data if the response is SharedMany.Object> , provided by the SharedResponseExtension extensionno setter - message → String
-
Additional information about the operation.
final
- one → JSON?
-
Available on SharedResponse<
Expect a single JSON data if the response is SharedOne.Object> , provided by the SharedResponseExtension extensionno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Indicates whether the operation was successful.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited